@@ -1,5 +1,7 @@
 package XML::Spice;
-$XML::Spice::VERSION = '0.04';
+$XML::Spice::VERSION = '0.05';
+# ABSTRACT: generating XML has never been so Perly!
+
 require 5.008;
 
 use warnings;
@@ -180,14 +182,14 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
+=for markdown [![Build Status](https://secure.travis-ci.org/robn/XML-Spice.png)](http://travis-ci.org/robn/XML-Spice)
+
 =head1 NAME
 
 XML::Spice - generating XML has never been so Perly!
 
-=head1 VERSION
-
-version 0.04
-
 =head1 SYNOPSIS
 
     use XML::Spice qw(html head title body h1 p a);
@@ -444,24 +446,38 @@ declaration of namespaces and use of prefixes, and so forth. The method used
 may change between releases, producing different results. If you require exact
 control over the details of the XML produced, then this module is not for you.
 
-=head2 REPORTING BUGS
+=head1 SUPPORT
 
-Please report bugs via the CPAN Request Tracker at
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-Spice>
+=head2 Bugs / Feature Requests
 
-=head1 FEEDBACK
+Please report any bugs or feature requests through the issue tracker
+at L<https://github.com/robn/XML-Spice/issues>.
+You will be notified automatically of any progress on your issue.
 
-If you find this module useful, please consider rating it on the CPAN Ratings
-service at L<http://cpanratings.perl.org/rate?distribution=XML-Spice>.
+=head2 Source Code
 
-If you like (or hate) this module, please tell the author! Send mail to
-E<lt>rob@eatenbyagrue.org<gt>.
+This is open source software. The code repository is available for
+public review and contribution under the terms of the license.
 
-=head1 AUTHOR
+L<https://github.com/robn/XML-Spice>
 
-Copyright 2006-2013 Robert Norris E<lt>rob@eatenbyagrue.orgE<gt>.
+  git clone https://github.com/robn/XML-Spice.git
 
-=head1 LICENSE
+=head1 AUTHORS
 
-This module is free software, you can redistribute it and/or modify it under
-the same terms as Perl itself.
+=over 4
+
+=item *
+
+Robert Norris <rob@eatenbyagrue.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2006-2016 by Robert Norris.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
